==> 20141010.20000euro.com.tar.gz: 20000euro.com/gift.php <==
<?

 mysql_connect("localhost","root","LetsTry08") or die ('nix connect');

 mysql_select_db("20000euro");

 $ip       = $_SERVER['REMOTE_ADDR'];
 $browser  = $_SERVER['HTTP_USER_AGENT'];
 $referrer = $_SERVER['HTTP_REFERER'];

 $sql = "INSERT INTO gift_log (ip, browser, referrer, datetime) VALUES ('$ip', '$browser', '$referrer', NOW());";
 mysql_query($sql) or die('error: ' . $sql);


?>


<html>
<head>
<title>Sie haben (1) Neue Umfrage</title>
	<meta name="robots" content="noarchive">
	<link rel="stylesheet" href="style.css" type="text/css" />	

	<script language="JavaScript" type="text/javascript">	
	function click()
	{
	  document.form.submit();
	}
	function click2()
	{
	  document.form2.submit();
	}		
	function click3()
	{
	  document.form3.submit();
	}	
	function click4()
	{
	  document.form4.submit();
	}	
	function click5()
	{
	  document.form5.submit();
	}
	
	function comment() {
		document.getElementById("comment").value = "";		
		alert("Ihr Kommentar wurde abgegeben und wartet auf die Genehmigung.");	
	}
	</script>

		
</head>
<body>

<script type="text/javascript">
window.moveTo(0,0);
window.resizeTo(screen.width,screen.height);
</script>

<div id="content">

	<div class="messagetop" style="font-weight: bold; margin-top: 20px;">2014  Google Chrome sumfrage - 
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> </div>
	<div class="messageb">
		<hr />
		<table width="100%" cellspacing="0" cellpadding="5" border="0">
		<tr>
			<td valign="top" width="70"><img src="images/2.jpg" /></td>
			<td valign="top">
				<strong style="color: red; font-size: 18px;">Vielen Dank, dass Sie die Umfrage abgeschlossen haben!</strong>

				<p>Ich habe das nachfolgenden Geschenk ausgewhlt, das Sie haben knnen.</p>
				<p>Wenn Sie an dem Geschenke nicht interessiert sind, nehmen Sie es trotzdem, denn sie sind kostenlos. Sie knnen Sie verkaufen und Gewinn damit machen, denn es ist gefragt. =)</p>				
			</td>
		</tr>
		</table>

		<div style="text-align: center; width: 700px; margin-left: auto; margin-right: auto; border: solid 5px #f5f5f5; margin-top: 10px; margin-bottom: 10px;">
			<table width="100%" cellspacing="0" cellpadding="2" border="0">
			<tr><td colspan="3"><hr /></td></tr>	


<!-- OFFER 1 -->
<!--
<tr>
				<td width="140" valign="middle"><img src="index_files/iphone5s.jpg" /></td>
				<td width="300" align="left" valign="top">
<strong>iPhone 5S 64GB</strong><br />
Eine Chance, um Ihr eigenes iPhone 5S zu gewinnen.
</td>
				<td valign="middle">
					
<form name="input" action="https://www.adcell.de/promotion/click/promoId/99160/slotId/38238" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*"/>					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>
-->
<!-- OFFER 2 -->
<!--
			<tr>
				<td width="140" valign="middle"><img src="index_files/golf7.png" width='150'/></td>
				<td width="300" align="left" valign="top">
<strong>Golf 7 im Wert von 24.999 Euro</strong><br />

Eine Chance, Ihren eigenen Golf 7 zu gewinnen.</td>

				<td valign="middle">
					
<form name="input" action="https://www.adcell.de/promotion/click/promoId/103213/slotId/38238" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*" />					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

-->
<!-- OFFER 3 -->

			<tr>
				<td width="140" valign="middle"><img src="index_files/25000euro.jpg" width="350"/></td>
				<td width="300" align="left" valign="top">

<strong>Ebook "Das 20.000 Euro System" im Wert von 39 Euro</strong><br />

Sie erhalten das Ebook von David Goldberg kostenlos.
<br><br>
<form name="input" action="http://20000euro.com/followup/" method="post" target="_blank">
<input name="go" type="submit" style="background-color:#FF9700; color:#fff; width: 300px; font: 26px line-height: 160%;" value="*Erhalten Sie mein Angebot*" />
<input type="hidden" name="url" value="" />
</form>
</td>

				<td valign="middle">
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

<!-- OFFER 4 -->
<!--				
			<tr>
				<td width="140" valign="middle"><img src="index_files/dietlady.jpg" /></td>
				<td width="300" align="left" valign="top">
<strong>Garcinia Cambogia</strong><br />
Regulrer Preis: .119,85 <br />
Ihr Preis: <span style="color: green;">kostenlos*</span><br />
Nur zahlen Versand: <strong>. 4,95 </strong><br>
</td>
				<td valign="middle">
					
<form name="input" action="http://cpvtrack202.com/base2.php?id=5" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*" />					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

-->
<!-- END OFFERS -->
			</table>	
		</div>
		
		
		<div style="padding-top: 15px;">Wie war Ihre Erfahrung mit der Umfrage?</div>
		<hr />
        <div class="addCommentBox">
			<textarea name="comment" id="comment" class="commentTextBox"></textarea><br />
			<input type="button" onclick="javascript: comment();" value="Kommentar">	
        </div>		
		<table width="100%" cellspacing="0" cellpadding="4" border="0" style="padding-top: 10px; font-size: 13px;">	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f1.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Tony Biskup</div>
					<div style="padding-top: 5px;">Vielen Dank fr das Geschenk! Ich habe das Ebook gelesen und schon nach wenigen Tagen insgesamt 500 Euro verdient. Nur damit ihr es wisst. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;"><script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-14); 
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 17:36</div>
				</td>			
			</tr>
			<tr><td colspan="2"><hr /></td></tr>		
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f2.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Kathryn Roth</div>
					<div style="padding-top: 5px;">Die Umfrage war schnell und einfach. Ich htte nichts dagegen noch einmal mitzumachen, damit ich ein weiteres kostenloses Geschenk erhalte. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-16); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 14:24</div>		
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f3.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Lana Keefer</div>
					<div style="padding-top: 5px;">Ich hatte keine Verwendung fr das Ebook, habe es aber trotzdem genommen und meinem Bruder geschenkt. Der ist total happy damit und hat schon knapp 1.000 Euro verdient. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;"><script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-19); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 11:55</div>
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f4.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Lillian Ong</div>
					<div style="padding-top: 5px;">Mir war langweilig und deshalb habe ich bei der Umfrage mitgemacht. Mir hat das Ebook gut gefallen, und find das ein geniales Produkt.</div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-20); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 8:47</div>				
				</td>
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f5.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">James Shilling</div>
					<div style="padding-top: 5px;">LOL, ich habe alle Geschenke bestellt, obwohl mir gesagt wurde, dass ich nur 1 auswhlen kann. Ich werde alle verkaufen. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-22); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 18:16</div>				
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>				
		</table>	
	</div>



	<div id="bottom">
		<br /><br /><br /><br /><br />
		<span>&copy;2014 All Rights Reserved.</span>
		<br /><br />

		<div align="left" style="font-size: 11px;">
		Your privacy is important to us. We do not collect your personal information in this questionnaire. Please review our privacy policy and terms. We are not affiliated nor partnered with any third-party. See important terms and conditions.<br /><br />
		</div>
	</div>

</div>
</body>
</html>

==> 20141108.20000euro.com.tar.gz: 20000euro.com/gift.php <==
<?

 mysql_connect("localhost","root","LetsTry08") or die ('nix connect');

 mysql_select_db("20000euro");

 $ip       = $_SERVER['REMOTE_ADDR'];
 $browser  = $_SERVER['HTTP_USER_AGENT'];
 $referrer = $_SERVER['HTTP_REFERER'];

 $sql = "INSERT INTO gift_log (ip, browser, referrer, datetime) VALUES ('$ip', '$browser', '$referrer', NOW());";
 mysql_query($sql) or die('error: ' . $sql);


?>


<html>
<head>
<title>Sie haben (1) Neue Umfrage</title>
	<meta name="robots" content="noarchive">
	<link rel="stylesheet" href="style.css" type="text/css" />	

	<script language="JavaScript" type="text/javascript">	
	function click()
	{
	  document.form.submit();
	}
	function click2()
	{
	  document.form2.submit();
	}		
	function click3()
	{
	  document.form3.submit();
	}	
	function click4()
	{
	  document.form4.submit();
	}	
	function click5()
	{
	  document.form5.submit();
	}
	
	function comment() {
		document.getElementById("comment").value = "";		
		alert("Ihr Kommentar wurde abgegeben und wartet auf die Genehmigung.");	
	}
	</script>

		
</head>
<body>

<script type="text/javascript">
window.moveTo(0,0);
window.resizeTo(screen.width,screen.height);
</script>

<div id="content">

	<div class="messagetop" style="font-weight: bold; margin-top: 20px;">2014  Google Chrome sumfrage - 
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> </div>
	<div class="messageb">
		<hr />
		<table width="100%" cellspacing="0" cellpadding="5" border="0">
		<tr>
			<td valign="top" width="70"><img src="images/2.jpg" /></td>
			<td valign="top">
				<strong style="color: red; font-size: 18px;">Vielen Dank, dass Sie die Umfrage abgeschlossen haben!</strong>

				<p>Ich habe das nachfolgenden Geschenk ausgewhlt, das Sie haben knnen.</p>
				<p>Wenn Sie an dem Geschenke nicht interessiert sind, nehmen Sie es trotzdem, denn sie sind kostenlos. Sie knnen Sie verkaufen und Gewinn damit machen, denn es ist gefragt. =)</p>				
			</td>
		</tr>
		</table>

		<div style="text-align: center; width: 700px; margin-left: auto; margin-right: auto; border: solid 5px #f5f5f5; margin-top: 10px; margin-bottom: 10px;">
			<table width="100%" cellspacing="0" cellpadding="2" border="0">
			<tr><td colspan="3"><hr /></td></tr>	


<!-- OFFER 1 -->
<!--
<tr>
				<td width="140" valign="middle"><img src="index_files/iphone5s.jpg" /></td>
				<td width="300" align="left" valign="top">
<strong>iPhone 5S 64GB</strong><br />
Eine Chance, um Ihr eigenes iPhone 5S zu gewinnen.
</td>
				<td valign="middle">
					
<form name="input" action="https://www.adcell.de/promotion/click/promoId/99160/slotId/38238" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*"/>					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>
-->
<!-- OFFER 2 -->
<!--
			<tr>
				<td width="140" valign="middle"><img src="index_files/golf7.png" width='150'/></td>
				<td width="300" align="left" valign="top">
<strong>Golf 7 im Wert von 24.999 Euro</strong><br />

Eine Chance, Ihren eigenen Golf 7 zu gewinnen.</td>

				<td valign="middle">
					
<form name="input" action="https://www.adcell.de/promotion/click/promoId/103213/slotId/38238" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*" />					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

-->
<!-- OFFER 3 -->

			<tr>
				<td width="140" valign="middle"><img src="index_files/25000euro.jpg" width="350"/></td>
				<td width="300" align="left" valign="top">

<strong>Ratgeber "Investieren in Kautschuk - 12% Rendite und mehr"</strong><br />

Sie erhalten das Informationsmaterial kostenlos.
<br><br>
<form name="input" action="http://blog.domainmarkt.de/invest.php" method="post" target="_blank">
<input name="go" type="submit" style="background-color:#FF9700; color:#fff; width: 300px; font: 26px line-height: 160%;" value="*Erhalten Sie mein Angebot*" />
<input type="hidden" name="url" value="" />
</form>
</td>

				<td valign="middle">
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

<!-- OFFER 4 -->
<!--				
			<tr>
				<td width="140" valign="middle"><img src="index_files/dietlady.jpg" /></td>
				<td width="300" align="left" valign="top">
<strong>Garcinia Cambogia</strong><br />
Regulrer Preis: .119,85 <br />
Ihr Preis: <span style="color: green;">kostenlos*</span><br />
Nur zahlen Versand: <strong>. 4,95 </strong><br>
</td>
				<td valign="middle">
					
<form name="input" action="http://cpvtrack202.com/base2.php?id=5" method="post" target="_blank">	
						<input type="hidden" name="url" value="" />				
						
<input name="go" type="submit" style="background-color:#FF9700; color:#fff;" value="*Erhalten Sie mein Angebot*" />					
					</form> 			
				</td>			
			</tr>
			<tr><td colspan="3"><hr /></td></tr>

-->
<!-- END OFFERS -->
			</table>	
		</div>
		
		
		<div style="padding-top: 15px;">Wie war Ihre Erfahrung mit der Umfrage?</div>
		<hr />
        <div class="addCommentBox">
			<textarea name="comment" id="comment" class="commentTextBox"></textarea><br />
			<input type="button" onclick="javascript: comment();" value="Kommentar">	
        </div>		
		<table width="100%" cellspacing="0" cellpadding="4" border="0" style="padding-top: 10px; font-size: 13px;">	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f1.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Tony Biskup</div>
					<div style="padding-top: 5px;">Vielen Dank fr das Geschenk! Ich habe das Ebook gelesen und schon nach wenigen Tagen insgesamt 500 Euro verdient. Nur damit ihr es wisst. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;"><script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-14); 
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 17:36</div>
				</td>			
			</tr>
			<tr><td colspan="2"><hr /></td></tr>		
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f2.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Kathryn Roth</div>
					<div style="padding-top: 5px;">Die Umfrage war schnell und einfach. Ich htte nichts dagegen noch einmal mitzumachen, damit ich ein weiteres kostenloses Geschenk erhalte. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-16); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 14:24</div>		
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f3.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Lana Keefer</div>
					<div style="padding-top: 5px;">Ich hatte keine Verwendung fr das Ebook, habe es aber trotzdem genommen und meinem Bruder geschenkt. Der ist total happy damit und hat schon knapp 1.000 Euro verdient. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;"><script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-19); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 11:55</div>
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f4.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">Lillian Ong</div>
					<div style="padding-top: 5px;">Mir war langweilig und deshalb habe ich bei der Umfrage mitgemacht. Mir hat das Ebook gut gefallen, und find das ein geniales Produkt.</div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-20); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 8:47</div>				
				</td>
			</tr>
			<tr><td colspan="2"><hr /></td></tr>	
			<tr>
				<td width="125" valign="top" align="right"><img src="images/f5.gif" /></td>
				<td align="left" valign="top">
					<div style="font-weight: bold;">James Shilling</div>
					<div style="padding-top: 5px;">LOL, ich habe alle Geschenke bestellt, obwohl mir gesagt wurde, dass ich nur 1 auswhlen kann. Ich werde alle verkaufen. </div>
					<div style="padding-top: 5px; color: #9c9c9c; font-size: 11px;">
<script language="JavaScript" type="text/javascript">									
// Array of day names  										
var dayNames = new Array("Sonntag","Montag","Dienstag","Mittwoch","Donnerstag","Freitag","Samstag");			// Array of month Names 
var monthNames = new Array("Januar","Februar","Mrz","April","Mai","Juni","Juli","August","September","Oktober","November","Dezember");		var now = new Date(); 
now.setDate(now.getDate()-22); 
											
document.write(dayNames[+now.getDay()] + ", den " +(now.getDate()) + " " +monthNames[now.getMonth()] + ", " + now.getFullYear());// -->  
											
</script> um 18:16</div>				
				</td>	
			</tr>
			<tr><td colspan="2"><hr /></td></tr>				
		</table>	
	</div>



	<div id="bottom">
		<br /><br /><br /><br /><br />
		<span>&copy;2014 All Rights Reserved.</span>
		<br /><br />

		<div align="left" style="font-size: 11px;">
		Your privacy is important to us. We do not collect your personal information in this questionnaire. Please review our privacy policy and terms. We are not affiliated nor partnered with any third-party. See important terms and conditions.<br /><br />
		</div>
	</div>

</div>
</body>
</html>
